@@ -16,7 +16,7 @@ typedef Eo Efl_Gfx_Hint;
  *
  * @since 1.23
  *
- * @ingroup Efl_Gfx
+ * @ingroup Efl_Gfx_Hint_Expand
  */
 #define EFL_GFX_HINT_EXPAND 1.000000
 #endif
@@ -26,7 +26,7 @@ typedef Eo Efl_Gfx_Hint;
  *
  * @since 1.23
  *
- * @ingroup Efl_Gfx
+ * @ingroup Efl_Gfx_Hint_Align_Left
  */
 #define EFL_GFX_HINT_ALIGN_LEFT 0.000000
 #endif
@@ -36,7 +36,7 @@ typedef Eo Efl_Gfx_Hint;
  *
  * @since 1.23
  *
- * @ingroup Efl_Gfx
+ * @ingroup Efl_Gfx_Hint_Align_Right
  */
 #define EFL_GFX_HINT_ALIGN_RIGHT 1.000000
 #endif
@@ -46,7 +46,7 @@ typedef Eo Efl_Gfx_Hint;
  *
  * @since 1.23
  *
- * @ingroup Efl_Gfx
+ * @ingroup Efl_Gfx_Hint_Align_Top
  */
 #define EFL_GFX_HINT_ALIGN_TOP 0.000000
 #endif
@@ -56,7 +56,7 @@ typedef Eo Efl_Gfx_Hint;
  *
  * @since 1.23
  *
- * @ingroup Efl_Gfx
+ * @ingroup Efl_Gfx_Hint_Align_Bottom
  */
 #define EFL_GFX_HINT_ALIGN_BOTTOM 1.000000
 #endif
@@ -66,7 +66,7 @@ typedef Eo Efl_Gfx_Hint;
  *
  * @since 1.23
  *
- * @ingroup Efl_Gfx
+ * @ingroup Efl_Gfx_Hint_Align_Center
  */
 #define EFL_GFX_HINT_ALIGN_CENTER 0.500000
 #endif
@@ -466,7 +466,7 @@ EOAPI void efl_gfx_hint_margin_get(const Eo *obj, int *l, int *r, int *t, int *b
  * hint as a boolean, but some others might consider it as a proportion, see
  * documentation of each container.
  *
- * @note Default weight hint values are 0.0, for both axis.
+ * @note Default weight hint values are 1.0, for both axis.
  *
  * @param[in] obj The object.
  * @param[in] x Non-negative double value to use as horizontal weight hint.
@@ -495,7 +495,7 @@ EOAPI void efl_gfx_hint_weight_set(Eo *obj, double x, double y);
  * hint as a boolean, but some others might consider it as a proportion, see
  * documentation of each container.
  *
- * @note Default weight hint values are 0.0, for both axis.
+ * @note Default weight hint values are 1.0, for both axis.
  *
  * @param[in] obj The object.
  * @param[out] x Non-negative double value to use as horizontal weight hint.
@@ -510,58 +510,40 @@ EOAPI void efl_gfx_hint_weight_get(const Eo *obj, double *x, double *y);
 /**
  * @brief Hints for an object's alignment.
  *
- * These are hints on how to align an object inside the boundaries of a
- * container/manager. Accepted values are in the 0.0 to 1.0 range.
- *
- * For the horizontal component, 0.0 means the start of the axis in the
- * direction that the current language reads, 1.0 means the end of the axis.
- *
- * For the vertical component, 0.0 to the top, 1.0 means to the bottom.
+ * These are hints on how to align this object inside the boundaries of its
+ * container/manager.
  *
  * This is not a size enforcement in any way, it's just a hint that should be
  * used whenever appropriate.
  *
- * @note Default alignment hint values are 0.5, for both axes.
- *
  * @param[in] obj The object.
- * @param[in] x Double, ranging from 0.0 to 1.0, where 0.0 is at the start of
- * the horizontal axis and 1.0 is at the end.
- * @param[in] y Double, ranging from 0.0 to 1.0, where 0.0 is at the start of
- * the vertical axis and 1.0 is at the end.
+ * @param[in] x Controls the horizontal alignment.
+ * @param[in] y Controls the vertical alignment.
  *
  * @since 1.22
  *
  * @ingroup Efl_Gfx_Hint
  */
-EOAPI void efl_gfx_hint_align_set(Eo *obj, double x, double y);
+EOAPI void efl_gfx_hint_align_set(Eo *obj, Efl_Gfx_Align x, Efl_Gfx_Align y);
 
 /**
  * @brief Hints for an object's alignment.
  *
- * These are hints on how to align an object inside the boundaries of a
- * container/manager. Accepted values are in the 0.0 to 1.0 range.
- *
- * For the horizontal component, 0.0 means the start of the axis in the
- * direction that the current language reads, 1.0 means the end of the axis.
- *
- * For the vertical component, 0.0 to the top, 1.0 means to the bottom.
+ * These are hints on how to align this object inside the boundaries of its
+ * container/manager.
  *
  * This is not a size enforcement in any way, it's just a hint that should be
  * used whenever appropriate.
  *
- * @note Default alignment hint values are 0.5, for both axes.
- *
  * @param[in] obj The object.
- * @param[out] x Double, ranging from 0.0 to 1.0, where 0.0 is at the start of
- * the horizontal axis and 1.0 is at the end.
- * @param[out] y Double, ranging from 0.0 to 1.0, where 0.0 is at the start of
- * the vertical axis and 1.0 is at the end.
+ * @param[out] x Controls the horizontal alignment.
+ * @param[out] y Controls the vertical alignment.
  *
  * @since 1.22
  *
  * @ingroup Efl_Gfx_Hint
  */
-EOAPI void efl_gfx_hint_align_get(const Eo *obj, double *x, double *y);
+EOAPI void efl_gfx_hint_align_get(const Eo *obj, Efl_Gfx_Align *x, Efl_Gfx_Align *y);
 
 /**
  * @brief Hints for an object's fill property that used to specify "justify" or
