@@ -13,8 +13,19 @@ typedef Eo Efl_Ui_Layout_Factory;
 
 
 #endif
-#ifdef EFL_BETA_API_SUPPORT
-/** Efl Ui Layout Factory class
+/**
+ * @brief @ref Efl_Ui_Factory that creates @ref Efl_Ui_Layout objects with
+ * caching.
+ *
+ * This factory is meant to be used by @ref Efl_Ui_View objects that use items
+ * with Layout and need the items to be created, updated, their model set and
+ * connected automatically before the @ref Efl_Ui_View receives the item
+ * instance.
+ *
+ * This class inherits from @ref Efl_Ui_Caching_Factory and inherits all its
+ * properties.
+ *
+ * @since 1.24
  *
  * @ingroup Efl_Ui_Layout_Factory
  */
@@ -23,16 +34,18 @@ typedef Eo Efl_Ui_Layout_Factory;
 EWAPI const Efl_Class *efl_ui_layout_factory_class_get(void);
 
 /**
- * @brief No description supplied.
+ * @brief Set the theme that will be applied to the created @ref Efl_Ui_Layout
+ * objects. See @ref efl_ui_layout_theme_get for more details.
  *
  * @param[in] obj The object.
  * @param[in] klass The class of the group.
  * @param[in] group The group.
- * @param[in] style The style to used.
+ * @param[in] style The style to use.
+ *
+ * @since 1.24
  *
  * @ingroup Efl_Ui_Layout_Factory
  */
 EOAPI void efl_ui_layout_factory_theme_config(Eo *obj, const char *klass, const char *group, const char *style);
-#endif /* EFL_BETA_API_SUPPORT */
 
 #endif
